@@ -28,7 +28,7 @@ class BaseCracker:
         debug: bool = False,
         check_useful: bool = False,
         max_retry_times: int = 3,
-        internal_proxy=False,
+        internal_proxy=True,
         **kwargs
     ) -> None:
         """
